
# Slot: node_type_list_is_correct


Whether the node types file can be assumed to be correct, i.e. does not have something wrong in it. If this parameter is passed as true on a malformed file, the constructor will crash.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_type_list_is_correct](https://w3id.org/neat/ensmallenRunConfig__node_type_list_is_correct)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
